==> apache-camel-quarkus-3.20.4-src.zip: camel-quarkus-3.20.4/extensions/kudu/deployment/src/main/java/org/apache/camel/quarkus/component/kudu/deployment/KuduProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.kudu.deployment;

import java.util.stream.Stream;

import com.sun.security.auth.module.JndiLoginModule;
import com.sun.security.auth.module.KeyStoreLoginModule;
import com.sun.security.auth.module.Krb5LoginModule;
import com.sun.security.auth.module.LdapLoginModule;
import com.sun.security.auth.module.NTLoginModule;
import com.sun.security.auth.module.UnixLoginModule;
import io.quarkus.deployment.annotations.BuildProducer;
import io.quarkus.deployment.annotations.BuildStep;
import io.quarkus.deployment.builditem.ExtensionSslNativeSupportBuildItem;
import io.quarkus.deployment.builditem.FeatureBuildItem;
import io.quarkus.deployment.builditem.nativeimage.NativeImageSecurityProviderBuildItem;
import io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem;
import io.quarkus.deployment.builditem.nativeimage.RuntimeReinitializedClassBuildItem;

class KuduProcessor {
    private static final String[] JDK_LOGIN_MODULE_CLASSES = {
            "com.sun.jmx.remote.security.FileLoginModule",
            JndiLoginModule.class.getName(),
            KeyStoreLoginModule.class.getName(),
            Krb5LoginModule.class.getName(),
            LdapLoginModule.class.getName(),
            NTLoginModule.class.getName(),
            UnixLoginModule.class.getName(),
    };
    private static final String FEATURE = "camel-kudu";

    @BuildStep
    FeatureBuildItem feature() {
        return new FeatureBuildItem(FEATURE);
    }

    @BuildStep
    ExtensionSslNativeSupportBuildItem activateSslNativeSupport() {
        return new ExtensionSslNativeSupportBuildItem(FEATURE);
    }

    @BuildStep
    NativeImageSecurityProviderBuildItem saslSecurityProvider() {
        return new NativeImageSecurityProviderBuildItem("com.sun.security.sasl.Provider");
    }

    @BuildStep
    void reflection(BuildProducer<ReflectiveClassBuildItem> reflectiveClass) {
        reflectiveClass.produce(ReflectiveClassBuildItem.builder(
                "org.apache.kudu.tserver.Tserver$ResourceMetricsPB",
                "org.apache.kudu.tserver.Tserver$ResourceMetricsPB$Builder")
                .methods()
                .build());

        reflectiveClass.produce(ReflectiveClassBuildItem.builder(JDK_LOGIN_MODULE_CLASSES).build());
    }

    @BuildStep
    void runtimeReinitializedClasses(BuildProducer<RuntimeReinitializedClassBuildItem> runtimeReinitializedClass) {
        // Required due to Protobuf / Kudu usage of sun.misc.Unsafe to compute static field values
        Stream.of("com.google.protobuf.UnsafeUtil",
                "com.google.common.primitives.UnsignedBytes$LexicographicalComparatorHolder",
                "com.google.common.primitives.UnsignedBytes$LexicographicalComparatorHolder$UnsafeComparator",
                "org.apache.kudu.client.TableLocationsCache",
                "org.apache.kudu.client.PartitionSchema",
                "org.apache.kudu.client.PartitionSchema$BoundsComparator")
                .map(RuntimeReinitializedClassBuildItem::new)
                .forEach(runtimeReinitializedClass::produce);
    }
}

==> apache-camel-quarkus-3.29.0-src.zip: camel-quarkus-3.29.0/extensions/kudu/deployment/src/main/java/org/apache/camel/quarkus/component/kudu/deployment/KuduProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.kudu.deployment;

import java.util.stream.Stream;

import com.sun.security.auth.module.JndiLoginModule;
import com.sun.security.auth.module.KeyStoreLoginModule;
import com.sun.security.auth.module.Krb5LoginModule;
import com.sun.security.auth.module.LdapLoginModule;
import com.sun.security.auth.module.NTLoginModule;
import com.sun.security.auth.module.UnixLoginModule;
import io.quarkus.deployment.annotations.BuildProducer;
import io.quarkus.deployment.annotations.BuildStep;
import io.quarkus.deployment.builditem.ExtensionSslNativeSupportBuildItem;
import io.quarkus.deployment.builditem.FeatureBuildItem;
import io.quarkus.deployment.builditem.nativeimage.NativeImageSecurityProviderBuildItem;
import io.quarkus.deployment.builditem.nativeimage.ReflectiveClassBuildItem;
import io.quarkus.deployment.builditem.nativeimage.RuntimeInitializedClassBuildItem;
import io.quarkus.deployment.builditem.nativeimage.RuntimeReinitializedClassBuildItem;

class KuduProcessor {
    private static final String[] JDK_LOGIN_MODULE_CLASSES = {
            "com.sun.jmx.remote.security.FileLoginModule",
            JndiLoginModule.class.getName(),
            KeyStoreLoginModule.class.getName(),
            Krb5LoginModule.class.getName(),
            LdapLoginModule.class.getName(),
            NTLoginModule.class.getName(),
            UnixLoginModule.class.getName(),
    };
    private static final String FEATURE = "camel-kudu";

    @BuildStep
    FeatureBuildItem feature() {
        return new FeatureBuildItem(FEATURE);
    }

    @BuildStep
    ExtensionSslNativeSupportBuildItem activateSslNativeSupport() {
        return new ExtensionSslNativeSupportBuildItem(FEATURE);
    }

    @BuildStep
    NativeImageSecurityProviderBuildItem saslSecurityProvider() {
        return new NativeImageSecurityProviderBuildItem("com.sun.security.sasl.Provider");
    }

    @BuildStep
    void reflection(BuildProducer<ReflectiveClassBuildItem> reflectiveClass) {
        reflectiveClass.produce(ReflectiveClassBuildItem.builder(
                "org.apache.kudu.tserver.Tserver$ResourceMetricsPB",
                "org.apache.kudu.tserver.Tserver$ResourceMetricsPB$Builder")
                .methods()
                .build());

        reflectiveClass.produce(ReflectiveClassBuildItem.builder(JDK_LOGIN_MODULE_CLASSES).build());
    }

    @BuildStep
    void runtimeReinitializedClasses(BuildProducer<RuntimeReinitializedClassBuildItem> runtimeReinitializedClass) {
        // Required due to Protobuf / Kudu usage of sun.misc.Unsafe to compute static field values
        Stream.of("com.google.protobuf.UnsafeUtil",
                "com.google.common.primitives.UnsignedBytes$LexicographicalComparatorHolder",
                "com.google.common.primitives.UnsignedBytes$LexicographicalComparatorHolder$UnsafeComparator",
                "org.apache.kudu.client.TableLocationsCache",
                "org.apache.kudu.client.PartitionSchema",
                "org.apache.kudu.client.PartitionSchema$BoundsComparator")
                .map(RuntimeReinitializedClassBuildItem::new)
                .forEach(runtimeReinitializedClass::produce);
    }

    @BuildStep
    RuntimeInitializedClassBuildItem runtimeInitializedClasses() {
        return new RuntimeInitializedClassBuildItem("com.google.protobuf.JavaFeaturesProto");
    }
}
